@@ -51,9 +51,9 @@ diagnose <- function(.data, ...) {
 #' 
 #' # Select the variable to diagnose
 #' diagnose(jobchange, gender, experience, training_hours)
-#' diagnose(jobchange, -gender, -experience, -training_hours)
-#' diagnose(jobchange, "gender", "experience", "training_hours")
-#' diagnose(jobchange, 4, 9, 13)
+#' # diagnose(jobchange, -gender, -experience, -training_hours)
+#' # diagnose(jobchange, "gender", "experience", "training_hours")
+#' # diagnose(jobchange, 4, 9, 13)
 #' 
 #' # Using pipes ---------------------------------
 #' library(dplyr)
@@ -65,14 +65,14 @@ diagnose <- function(.data, ...) {
 #' jobchange %>%
 #'   diagnose(gender, experience, training_hours)
 #' # Negative values to drop variables
-#' jobchange %>%
-#'   diagnose(-gender, -experience, -training_hours)
+#' # jobchange %>%
+#' #   diagnose(-gender, -experience, -training_hours)
 #' # Positions values select variables
-#' jobchange %>%
-#'   diagnose(4, 9, 13)
+#' # # jobchange %>%
+#' #   diagnose(4, 9, 13)
 #' # Positions values select variables
-#' jobchange %>%
-#'   diagnose(-8, -9, -10)
+#' # jobchange %>%
+#' #   diagnose(-8, -9, -10)
 #'   
 #' # Using pipes & dplyr -------------------------
 #' # Diagnosis of missing variables
@@ -190,8 +190,8 @@ diagnose_category <- function(.data, ...) {
 #'  diagnose_category(company_type, job_chnge)
 #'  
 #' # Negative values to drop variables
-#' jobchange %>%
-#'   diagnose_category(-company_type, -job_chnge)
+#' # jobchange %>%
+#' #   diagnose_category(-company_type, -job_chnge)
 #'   
 #' # Positions values select variables
 #' # jobchange %>%
@@ -359,14 +359,14 @@ diagnose_numeric <- function(.data, ...) {
 #' heartfailure %>%
 #'   diagnose_numeric(cpk_enzyme, sodium)
 #' # Negative values to drop variables
-#' heartfailure %>%
-#'   diagnose_numeric(-cpk_enzyme, -sodium)
+#' # heartfailure %>%
+#' #   diagnose_numeric(-cpk_enzyme, -sodium)
 #' # Positions values select variables
-#' heartfailure %>%
-#'   diagnose_numeric(5)
+#' # heartfailure %>%
+#' #   diagnose_numeric(5)
 #' # Positions values select variables
-#' heartfailure %>%
-#'   diagnose_numeric(-1, -5)
+#' # heartfailure %>%
+#' #   diagnose_numeric(-1, -5)
 #'
 #' # Using pipes & dplyr -------------------------
 #' # List of variables containing outliers
@@ -471,9 +471,9 @@ diagnose_outlier <- function(.data, ...) {
 #' 
 #' # Select the variable to diagnose
 #' diagnose_outlier(heartfailure, cpk_enzyme, sodium)
-#' diagnose_outlier(heartfailure, -cpk_enzyme, -sodium)
-#' diagnose_outlier(heartfailure, "cpk_enzyme", "sodium")
-#' diagnose_outlier(heartfailure, 5)
+#' # diagnose_outlier(heartfailure, -cpk_enzyme, -sodium)
+#' # diagnose_outlier(heartfailure, "cpk_enzyme", "sodium")
+#' # diagnose_outlier(heartfailure, 5)
 #' 
 #' # Using pipes ---------------------------------
 #' library(dplyr)
@@ -484,15 +484,15 @@ diagnose_outlier <- function(.data, ...) {
 #' # Positive values select variables
 #' heartfailure %>%
 #'   diagnose_outlier(cpk_enzyme, sodium)
-#' # Negative values to drop variables
-#' heartfailure %>%
-#'   diagnose_outlier(-cpk_enzyme, -sodium)
+#' # # Negative values to drop variables
+#' # heartfailure %>%
+#' #   diagnose_outlier(-cpk_enzyme, -sodium)
+#' # # Positions values select variables
+#' # heartfailure %>%
+#' #   diagnose_outlier(5)
 #' # Positions values select variables
-#' heartfailure %>%
-#'   diagnose_outlier(5)
-#' # Positions values select variables
-#' heartfailure %>%
-#'   diagnose_outlier(-1, -5)
+#' # # heartfailure %>%
+#' #   diagnose_outlier(-1, -5)
 #' 
 #' # Using pipes & dplyr -------------------------
 #' # outlier_ratio is more than 1%
@@ -562,6 +562,10 @@ plot_outlier <- function(.data, ...) {
 #' Since the plot is drawn for each variable, if you specify more than
 #' one variable in the ... argument, the specified number of plots are drawn.
 #'
+#' The base_family is selected from "Roboto Condensed", "Liberation Sans Narrow",
+#' "NanumSquare", "Noto Sans Korean". If you want to use a different font, 
+#' use it after loading the Google font with import_google_font().
+#' 
 #' @section Outlier diagnostic information:
 #' The plot derived from the numerical data diagnosis is as follows.
 #'
@@ -585,6 +589,8 @@ plot_outlier <- function(.data, ...) {
 #' They support unquoting and splicing.
 #' @param col a color to be used to fill the bars. The default is "steelblue".
 #' @param typographic logical. Whether to apply focuses on typographic elements to ggplot2 visualization. 
+#' @param base_family character. The name of the base font family to use 
+#' for the visualization. If not specified, the font defined in dlookr is applied. (See details)
 #' The default is TRUE. if TRUE provides a base theme that focuses on typographic elements using hrbrthemes package.
 #' @seealso \code{\link{plot_outlier.tbl_dbi}}, \code{\link{diagnose_outlier.data.frame}}.
 #' @export
@@ -641,13 +647,15 @@ plot_outlier <- function(.data, ...) {
 #' @importFrom tidyselect vars_select
 #' @importFrom rlang quos
 #' @export
-plot_outlier.data.frame <- function(.data, ..., col = "steelblue", typographic = TRUE) {
+plot_outlier.data.frame <- function(.data, ..., col = "steelblue", 
+                                    typographic = TRUE, base_family = NULL) {
   vars <- tidyselect::vars_select(names(.data), !!! rlang::quos(...))
-  plot_outlier_impl(.data, vars, col, typographic)
+  plot_outlier_impl(.data, vars, col, typographic, base_family)
 }
 
 #' @importFrom graphics boxplot hist title par
-plot_outlier_impl <- function(df, vars, col = "steelblue", typographic = TRUE) {
+plot_outlier_impl <- function(df, vars, col = "steelblue", typographic = TRUE,
+                              base_family = NULL) {
   if (length(vars) == 0) vars <- names(df)
 
   if (length(vars) == 1 & !tibble::is_tibble(df)) 
@@ -655,11 +663,11 @@ plot_outlier_impl <- function(df, vars, col = "steelblue", typographic = TRUE) {
 
   idx_numeric <- find_class(df[, vars], type = "numerical")
   
-  plot_outliers <- function(df, var, col, typographic) {
+  plot_outliers <- function(df, var, col, typographic, base_family) {
     x <- dplyr::pull(df, var)
     main <- sprintf("Outlier Diagnosis Plot (%s)", var)
     
-    plot_outlier_raw(x, main, col, typographic)
+    plot_outlier_raw(x, main, col, typographic, base_family)
   }
 
   if (length(idx_numeric) == 0) {
@@ -677,7 +685,7 @@ plot_outlier_impl <- function(df, vars, col = "steelblue", typographic = TRUE) {
     }
     
     tmp <- lapply(vars[idx_numeric][!idx_na],
-                  function(x) plot_outliers(df, x, col, typographic))
+                  function(x) plot_outliers(df, x, col, typographic, base_family))
   }
 }
 
@@ -685,7 +693,8 @@ plot_outlier_impl <- function(df, vars, col = "steelblue", typographic = TRUE) {
 #' @import hrbrthemes
 #' @importFrom gridExtra grid.arrange
 #' @importFrom grid textGrob gpar
-plot_outlier_raw <- function(x, main = NULL, col = "steelblue", typographic = TRUE) {
+plot_outlier_raw <- function(x, main = NULL, col = "steelblue", 
+                             typographic = TRUE, base_family = NULL) {
   main <- ifelse(is.null(main), "Outlier Diagnose Plot", main)
   
   df_all <- data.frame(x = x) %>% 
@@ -695,7 +704,7 @@ plot_outlier_raw <- function(x, main = NULL, col = "steelblue", typographic = TR
     filter(!is.na(x)) %>% 
     filter(!x  %in% boxplot.stats(x)$out)
   
-  # calulate number of bins using Sturges' formula
+  # calculate number of bins using Sturges' formula
   n_bins_all <- round(log2(nrow(df_all)) + 1)
   n_bins_out <- round(log2(nrow(df_out)) + 1)
   
@@ -704,6 +713,7 @@ plot_outlier_raw <- function(x, main = NULL, col = "steelblue", typographic = TR
     geom_boxplot(fill = col, color = "black", alpha = 0.8) +
     xlim(-0.7, 0.7) + 
     labs(title = "With outliers", x = "", y = "") +
+    theme_grey(base_family = base_family) +
     theme(axis.text.x = element_blank(),
           axis.ticks.x = element_blank())
   
@@ -712,53 +722,56 @@ plot_outlier_raw <- function(x, main = NULL, col = "steelblue", typographic = TR
     geom_boxplot(fill = col, color = "black", alpha = 0.8) +
     xlim(-0.7, 0.7) + 
     labs(title = "Without outliers", x = "", y = "") +
+    theme_grey(base_family = base_family) +
     theme(axis.text.x = element_blank(),
           axis.ticks.x = element_blank())
   
   top_right <- df_all %>% 
     ggplot(aes(x)) +
     geom_histogram(fill = col, color = "black", alpha = 0.8, bins = n_bins_all) +
-    labs(title = "With outliers", x = "", y = "")
+    labs(title = "With outliers", x = "", y = "") +
+    theme_grey(base_family = base_family)
   
   bottom_right <- df_out %>% 
     ggplot(aes(x)) +
     geom_histogram(fill = col, color = "black", alpha = 0.8, bins = n_bins_out) +
-    labs(title = "Without outliers", x = "", y = "")
+    labs(title = "Without outliers", x = "", y = "") +
+    theme_grey(base_family = base_family)
   
   if (typographic) {
     top_left <- top_left +
-      theme_typographic() +
+      theme_typographic(base_family) +
       theme(plot.title = element_text(size = 15, face = "plain"),
             axis.text.x = element_blank(),
             axis.ticks.x = element_blank(),
             plot.margin = margin(10, 30, 10, 30))
     
     top_right <- top_right +
-      theme_typographic() +
+      theme_typographic(base_family) +
       theme(plot.title = element_text(size = 15, face = "plain"),
             plot.margin = margin(10, 30, 10, 30))
     
     bottom_left <- bottom_left +
-      theme_typographic() +
+      theme_typographic(base_family) +
       theme(plot.title = element_text(size = 15, face = "plain"),
             axis.text.x = element_blank(),
             axis.ticks.x = element_blank(),
             plot.margin = margin(10, 30, 10, 30))
     
     bottom_right <- bottom_right +
-      theme_typographic() +
+      theme_typographic(base_family) +
       theme(plot.title = element_text(size = 15, face = "plain"),
             plot.margin = margin(10, 30, 10, 30))    
-    
-    fontfamily <- get_font_family()
-    
-    top <- grid::textGrob(main, gp = grid::gpar(fontfamily = fontfamily, 
-                                                fontsize = 18, font = 2),
-                          x = unit(0.075, "npc"), just = "left")
-  } else {
-    top <- main
+  } 
+  
+  if (is.null(base_family)) {
+    base_family <- "Roboto Condensed"     
   }
   
+  top <- grid::textGrob(main, gp = grid::gpar(fontfamily = base_family, 
+                                              fontsize = 18, font = 2),
+                        x = unit(0.075, "npc"), just = "left")    
+  
   suppressWarnings(gridExtra::grid.arrange(top_left, top_right, bottom_left, bottom_right, 
                                            ncol = 2, nrow = 2, widths = c(2, 3), top = top))
 }
@@ -773,6 +786,10 @@ plot_outlier_raw <- function(x, main = NULL, col = "steelblue", typographic = TR
 #' Since the plot is drawn for each variable, if you specify more than
 #' one variable in the ... argument, the specified number of plots are drawn.
 #'
+#' The base_family is selected from "Roboto Condensed", "Liberation Sans Narrow",
+#' "NanumSquare", "Noto Sans Korean". If you want to use a different font, 
+#' use it after loading the Google font with import_google_font().
+#' 
 #' @section Outlier diagnostic information:
 #' The plot derived from the numerical data diagnosis is as follows.
 #'
@@ -793,6 +810,8 @@ plot_outlier_raw <- function(x, main = NULL, col = "steelblue", typographic = TR
 #' where column names represent column positions.
 #' They support unquoting and splicing.
 #' @param typographic logical. Whether to apply focuses on typographic elements to ggplot2 visualization. 
+#' @param base_family character. The name of the base font family to use 
+#' for the visualization. If not specified, the font defined in dlookr is applied. (See details)
 #' The default is TRUE. if TRUE provides a base theme that focuses on typographic elements using hrbrthemes package.
 #' @seealso \code{\link{plot_outlier.data.frame}}.
 #' @export
@@ -801,7 +820,7 @@ plot_outlier_raw <- function(x, main = NULL, col = "steelblue", typographic = TR
 #' categ <- target_by(heartfailure, death_event)
 #' 
 #' plot_outlier(categ, sodium)
-#' plot_outlier(categ, sodium, typographic = FALSE)
+#' # plot_outlier(categ, sodium, typographic = FALSE)
 #' 
 #' # death_eventing dplyr
 #' library(dplyr)
@@ -825,16 +844,16 @@ plot_outlier_raw <- function(x, main = NULL, col = "steelblue", typographic = TR
 #' @importFrom tidyselect vars_select
 #' @importFrom rlang quos
 #' @export
-plot_outlier.target_df <- function(.data, ..., typographic = TRUE) {
+plot_outlier.target_df <- function(.data, ..., typographic = TRUE, base_family = NULL) {
   vars <- tidyselect::vars_select(names(.data), !!! rlang::quos(...))
-  plot_outlier_target_impl(.data, vars, typographic)
+  plot_outlier_target_impl(.data, vars, typographic, base_family)
 }
 
 #' @import dplyr
 #' @import ggplot2
 #' @importFrom tibble is_tibble
 #' @importFrom gridExtra grid.arrange
-plot_outlier_target_impl <- function(df, vars, typographic = TRUE) {
+plot_outlier_target_impl <- function(df, vars, typographic = TRUE, base_family = NULL) {
   if (utils::packageVersion("dplyr") >= "0.8.0") {
     target <- setdiff(attr(df, "groups") %>% names(), ".rows")
   } else {
@@ -869,36 +888,40 @@ plot_outlier_target_impl <- function(df, vars, typographic = TRUE) {
     invisible(NULL)
   }
   
-  plot_outliers <- function(df, target, predictor, typographic = TRUE) {
+  plot_outliers <- function(df, target, predictor, typographic = TRUE, base_family = NULL) {
     data_with <- df %>% 
       ungroup() %>% 
       select(target, predictor) %>% 
       filter(!is.na(target))
     
-    box_with <- ggplot(data_with, aes_string(x = target, y = predictor, fill = target)) +
+    box_with <- ggplot(data_with, aes(x = !!sym(target), y = !!sym(predictor), fill = !!sym(target))) +
       geom_boxplot(alpha = 0.8) +
       labs(title = "boxplot with outliers") +
+      theme_grey(base_family = base_family) +
       theme(legend.position = "none")
     
-    density_with <- ggplot(data_with, aes_string(x = predictor, colour = target)) +
+    density_with <- ggplot(data_with, aes(x = !!sym(predictor), colour = !!sym(target))) +
       geom_density() +
-      labs(title = "density with outliers") 
+      labs(title = "density with outliers") +
+      theme_grey(base_family = base_family)
     
     flag <- !data_with[, predictor] %>% pull %in% boxplot.stats(data_with[, predictor] %>% pull)$out
     data_without <- data_with[flag, ]
     
-    box_without <- ggplot(data_without, aes_string(x = target, y = predictor, fill = target)) +
+    box_without <- ggplot(data_without, aes(x = !!sym(target), y = !!sym(predictor), fill = !!sym(target))) +
       geom_boxplot(alpha = 0.8) +
       labs(title = "boxplot without outliers") +
+      theme_grey(base_family = base_family) +
       theme(legend.position = "none")
     
-    density_without <- ggplot(data_without, aes_string(x = predictor, colour = target)) +
+    density_without <- ggplot(data_without, aes(x = !!sym(predictor), colour = !!sym(target))) +
       geom_density() +
-      labs(title = "density with outliers") 
+      labs(title = "density with outliers") +
+      theme_grey(base_family = base_family)
     
     if (typographic) {
       box_with <- box_with +
-        theme_typographic() +
+        theme_typographic(base_family) +
         scale_fill_ipsum() + 
         theme(legend.position = "none",
               plot.title = element_text(size = 15),
@@ -909,7 +932,7 @@ plot_outlier_target_impl <- function(df, vars, typographic = TRUE) {
               plot.margin = margin(10, 30, 10, 10))
       
       density_with <- density_with +
-        theme_typographic() +
+        theme_typographic(base_family) +
         scale_color_ipsum() +
         theme(plot.title = element_text(size = 15),
               axis.title.x = element_text(size = 12),
@@ -919,7 +942,7 @@ plot_outlier_target_impl <- function(df, vars, typographic = TRUE) {
               plot.margin = margin(10, 30, 10, 10))
       
       box_without <- box_without +
-        theme_typographic() +
+        theme_typographic(base_family) +
         scale_fill_ipsum() + 
         theme(legend.position = "none",
               plot.title = element_text(size = 15),
@@ -930,7 +953,7 @@ plot_outlier_target_impl <- function(df, vars, typographic = TRUE) {
               plot.margin = margin(10, 30, 10, 10))
       
       density_without <- density_without +
-        theme_typographic() +
+        theme_typographic(base_family) +
         scale_color_ipsum() +
         theme(plot.title = element_text(size = 15),
               axis.title.x = element_text(size = 12),
@@ -961,7 +984,7 @@ plot_outlier_target_impl <- function(df, vars, typographic = TRUE) {
     }
     
     tmp <- lapply(vars[idx_numeric][!idx_na],
-                  function(x) plot_outliers(df, target, x, typographic))
+                  function(x) plot_outliers(df, target, x, typographic, base_family))
   }
 }
 
@@ -1034,14 +1057,14 @@ diagnose_report <- function(.data, output_format, output_file, output_dir, ...)
 #' # create pdf file. file name is DataDiagnosis_Report.pdf
 #' diagnose_report(heartfailure)
 #' # create pdf file. file name is Diagn.pdf
-#' diagnose_report(heartfailure, output_file = "Diagn.pdf")
+#' # diagnose_report(heartfailure, output_file = "Diagn.pdf")
 #' # create pdf file. file name is ./Diagn.pdf and not browse
 #' # diagnose_report(heartfailure, output_dir = ".", output_file = "Diagn.pdf", 
 #' #   browse = FALSE)
 #' # create html file. file name is Diagnosis_Report.html
-#' diagnose_report(heartfailure, output_format = "html")
+#' # diagnose_report(heartfailure, output_format = "html")
 #' # create html file. file name is Diagn.html
-#' diagnose_report(heartfailure, output_format = "html", output_file = "Diagn.html")
+#' # diagnose_report(heartfailure, output_format = "html", output_file = "Diagn.html")
 #' }
 #'
 #' @importFrom knitr knit2pdf
