@@ -65,14 +65,14 @@
 #' 
 #' # Replace the missing value of the platelets variable with rpart
 #' # The target variable is death_event.
-#' imputate_na(heartfailure2, platelets, death_event, method = "rpart")
+#' # imputate_na(heartfailure2, platelets, death_event, method = "rpart")
 #' 
 #' # Replace the missing value of the smoking variable with mode
-#' imputate_na(heartfailure2, smoking, method = "mode")
+#' # imputate_na(heartfailure2, smoking, method = "mode")
 #' 
 #' # Replace the missing value of the smoking variable with mice
 #' # The target variable is death_event.
-#' imputate_na(heartfailure2, smoking, death_event, method = "mice")
+#' # imputate_na(heartfailure2, smoking, death_event, method = "mice")
 #' 
 #' ## using dplyr -------------------------------------
 #' library(dplyr)
@@ -93,9 +93,9 @@
 #' # plot(platelets)
 #' 
 #' # If the variable of interest is a categorical variable
-#' smoking <- imputate_na(heartfailure2, smoking, death_event, method = "mice")
-#' smoking
-#' summary(smoking)
+#' # smoking <- imputate_na(heartfailure2, smoking, death_event, method = "mice")
+#' # smoking
+#' # summary(smoking)
 #' 
 #' # plot(smoking)
 #' }
@@ -222,7 +222,7 @@ imputate_na_impl <- function(df, xvar, yvar, method, seed = NULL,
     }
     
     if (requireNamespace("rpart", quietly = TRUE)) {
-      model <- rpart::rpart(sprintf("%s ~ .", x),
+      model <- rpart::rpart(sprintf("`%s` ~ .", x),
                             data = df[!is.na(pull(df, x)), setdiff(intersect(names(df), complete_flag), y)],
                             method = method, na.action = na.omit)
     } else {
@@ -354,8 +354,8 @@ imputate_na_impl <- function(df, xvar, yvar, method, seed = NULL,
 #' # Replace the outliers of the sodium variable with median.
 #' imputate_outlier(heartfailure, sodium, method = "median")
 #' 
-#' # Replace the outliers of the sodium variable with capping.
-#' imputate_outlier(heartfailure, sodium, method = "capping")
+#' # # Replace the outliers of the sodium variable with capping.
+#' # imputate_outlier(heartfailure, sodium, method = "capping")
 #' 
 #' ## using dplyr -------------------------------------
 #' library(dplyr)
@@ -500,9 +500,9 @@ imputate_outlier_impl <- function(df, xvar, method, no_attrs = FALSE) {
 #' plot(platelets)
 #'
 #' # If the variable of interest is a categorical variables
-#' smoking <- imputate_na(heartfailure2, smoking, death_event, method = "mice")
-#' smoking
-#' summary(smoking)
+#' # smoking <- imputate_na(heartfailure2, smoking, death_event, method = "mice")
+#' # smoking
+#' # # summary(smoking)
 #' 
 #' # plot(smoking)
 #'
@@ -605,10 +605,16 @@ summary.imputation <- function(object, ...) {
 #' The imputation of a numerical variable is a density plot,
 #' and the imputation of a categorical variable is a bar plot.
 #'
+#' @details The base_family is selected from "Roboto Condensed", "Liberation Sans Narrow",
+#' "NanumSquare", "Noto Sans Korean". If you want to use a different font, 
+#' use it after loading the Google font with import_google_font().
+#' 
 #' @param x an object of class "imputation", usually, a result of a call to imputate_na()
 #' or imputate_outlier().
 #' @param typographic logical. Whether to apply focuses on typographic elements to ggplot2 visualization. 
 #' The default is TRUE. if TRUE provides a base theme that focuses on typographic elements using hrbrthemes package.
+#' @param base_family character. The name of the base font family to use 
+#' for the visualization. If not specified, the font defined in dlookr is applied. (See details)
 #' @param ... arguments to be passed to methods, such as graphical parameters (see par).
 #' only applies when the model argument is TRUE, and is used for ... of the plot.lm() function.
 #' @seealso \code{\link{imputate_na}}, \code{\link{imputate_outlier}}, \code{\link{summary.imputation}}.
@@ -628,11 +634,11 @@ summary.imputation <- function(object, ...) {
 #' plot(platelets)
 #'
 #' # If the variable of interest is a categorical variables
-#' smoking <- imputate_na(heartfailure2, smoking, death_event, method = "mice")
-#' smoking
-#' summary(smoking)
+#' # smoking <- imputate_na(heartfailure2, smoking, death_event, method = "mice")
+#' # smoking
+#' # summary(smoking)
 #' 
-#' plot(smoking)
+#' # plot(smoking)
 #'
 #' # Impute outliers ----------------------------------
 #' # If the variable of interest is a numerical variable
@@ -647,7 +653,7 @@ summary.imputation <- function(object, ...) {
 #' @import hrbrthemes
 #' @importFrom tidyr gather
 #' @export
-plot.imputation <- function(x, typographic = TRUE, ...) {
+plot.imputation <- function(x, typographic = TRUE, base_family = NULL, ...) {
   type <- attr(x, "type")
   var_type <- attr(x, "var_type")
   method <- attr(x, "method")
@@ -675,11 +681,12 @@ plot.imputation <- function(x, typographic = TRUE, ...) {
       tidyr::gather() %>%
       ggplot(aes(x = value, color = key)) +
       geom_density(na.rm = TRUE) +
-      labs(title = sprintf("imputation method : %s", method))})
+      labs(title = sprintf("imputation method : %s", method))}) +
+      theme_grey(base_family = base_family)
     
     if (typographic) {
       p <- p +
-        theme_typographic() +
+        theme_typographic(base_family) +
         scale_color_ipsum() +
         theme(
           axis.title.x = element_text(size = 13),
@@ -694,11 +701,12 @@ plot.imputation <- function(x, typographic = TRUE, ...) {
       ggplot(aes(x = value, fill = key)) +
       geom_bar(position = "dodge") +
       labs(title = sprintf("imputation method : %s", method),
-            x = "level", y = "frequency")})
+            x = "level", y = "frequency")}) +
+      theme_grey(base_family = base_family)
     
     if (typographic) {
       p <- p +
-        theme_typographic() +
+        theme_typographic(base_family) +
         scale_fill_ipsum() +
         theme(
           axis.title.x = element_text(size = 13),
